### Name: default.itemps
### Title: Default Sigmoidal, Harmonic and Geometric Temperature Ladders
### Aliases: default.itemps
### Keywords: misc

### ** Examples

## comparing the different ladders
geo <- default.itemps(type="geometric")
har <- default.itemps(type="harmonic")
sig <- default.itemps(type="sigmoidal")
par(mfrow=c(2,1))
matplot(cbind(geo$k, har$k, sig$k), pch=c(21,22,23),
        cex=1.5, main="3 inv-temp ladders", xlab="indx",
        ylab="itemp")
legend("topright", pch=c(21,22,23), 
       c("geometric","harmonic","sigmoidal"), col=c(1,2,3))
matplot(log(cbind(sig$k, geo$k, har$k)), pch=c(21,22,23),
        cex=1.5, main="3 log(inv-temp) ladders", xlab="indx",
        ylab="itemp")

## using Importance Tempering (IT) to improve mixing
## on the motorcycle accident dataset
library(MASS)
out.it <- btgpllm(X=mcycle[,1], Z=mcycle[,2], BTE=c(2000,22000,2),
        R=3, itemps=default.itemps(), m0r1=TRUE, bprior="b0",
        trace=TRUE, pred.n=FALSE)

## compare to regular tgp w/o IT
out.reg <- btgpllm(X=mcycle[,1], Z=mcycle[,2], BTE=c(2000,22000,2),
        R=3, m0r1=TRUE, bprior="b0", trace=TRUE, pred.n=FALSE)

## compare the heights explored by the three chains:
## REG, combining all temperatures, and IT
L <- length(out.it$trace$post$height)
hw <- suppressWarnings(sample(out.it$trace$post$height, L,
            prob=out.it$trace$post$wlambda, replace=TRUE))
b <- hist2bar(cbind(out.reg$trace$post$height,
             out.it$trace$post$height, hw))
par(mfrow=c(1,1))
barplot(b, beside=TRUE, xlab="tree height", ylab="counts", col=1:3,
        main="tree heights encountered")
legend("topright", c("reg MCMC", "All Temps", "IT"), fill=1:3)



